#--------------------------------------------------------------------------------------------#
#                                                                                            #
#   LIMIT Cord Blood DNA Methylation                                                         #
#   Processing and Analyses for Paper 2: Comparing Normalisation and Processing Strategies   #
#                                                                                            #
#--------------------------------------------------------------------------------------------#


# Libraries ----

library(limma)
library(sva)

# Need to set up manual file path because can't save the data in the same place as the code (no room on disk)

datpath <- file.path("/Volumes/JENNIE/O&G data/LIMIT DNAm Data")
datpath <- file.path("F:/O&G data/LIMIT DNAm Data")

#--------------------------------
# Make a Fake Group Variable ----
#--------------------------------

# metadata (with estimated cell type proportions)

metadata <- readRDS(paste0(datpath, "/Main paper data/Analysis Datasets/metadata_with_cell.RDS"))

set.seed(14920)
metadata$fakegrp <- rbinom(645, 1, 0.5)
metadata$fakegrp <- factor(metadata$fakegrp, levels=c(0,1), labels=c("Tabby", "Tortoiseshell"))
table(metadata$fakegrp)
table(metadata$Treatment, metadata$fakegrp)

metadata$fakegrp2 <- with(metadata, ifelse(fakegrp=="Tabby", rbinom(326, 1, 0.6), rbinom(319, 1, 0.6)))
with(metadata, table(fakegrp, fakegrp2))
metadata$fakegrp2 <- factor(metadata$fakegrp2, levels=c(0,1), labels=c("Long", "Short"))

metadata$fakeint <- with(metadata, paste(fakegrp, fakegrp2, sep="_"))

metafake <- subset(metadata, select=c("StudyID", "sample", "Sentrix_Barcode", "BSex", "fakegrp", "fakegrp2", "fakeint",
                                      "Bcell", "CD4T", "CD8T", "Gran", "Mono", "NK", "nRBC"))

saveRDS(metafake, file=paste0(datpath,"/Methods Comparison Data/Model Fit Results/metafake.RDS"))

# design matrix
fakemod1 <- model.matrix(~ fakegrp*fakegrp2 + BSex, data=metafake)
fakemod2 <- model.matrix(~ fakegrp*fakegrp2 + BSex + factor(Sentrix_Barcode), data=metafake)
fakemod3 <- model.matrix(~ fakegrp*fakegrp2 + BSex + factor(Sentrix_Barcode) + 
                            Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metafake)
fakemod4 <- model.matrix(~ fakegrp*fakegrp2 + BSex + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metafake)

#---------------------------------------------------------------
# ComBat Processing and Analysis for QN Data and Fake Group ----
#---------------------------------------------------------------

qn.mvals <- readRDS(paste0(datpath, "/Main paper data/Analysis Datasets/qn.mvals.main.RDS"))

qn_f1 <- ComBat(qn.mvals, batch=metafake$Sentrix_Barcode, mod=fakemod1)
qn_f2 <- ComBat(qn.mvals, batch=metafake$Sentrix_Barcode)

## Analyses ##

# run limma on non-ComBat processed dataset, adjusting for batch and also getting effect of infant sex
metafake <- metafake[match(metafake$sample, colnames(qn.mvals)),]
qn1_nocb <- lmFit(qn.mvals, fakemod1) # no adjustment
qn2_nocb <- lmFit(qn.mvals, fakemod2) # adjust for batch
qn3_nocb <- lmFit(qn.mvals, fakemod3) # adjust for batch and cell type proportion
qn4_nocb <- lmFit(qn.mvals, fakemod4) # adjust only for cell type proportion

# ComBat-processed dataset
metafake <- metafake[match(metafake$sample, colnames(qn_f1)),]
qn1_cbeff <- lmFit(qn_f1, fakemod1)
qn2_cbeff <- lmFit(qn_f1, fakemod2)
qn3_cbeff <- lmFit(qn_f1, fakemod3)
qn4_cbeff <- lmFit(qn_f1, fakemod4)

metafake <- metafake[match(metafake$sample, colnames(qn_f2)),]
qn1_cb <- lmFit(qn_f2, fakemod1)
qn2_cb <- lmFit(qn_f2, fakemod2)
qn3_cb <- lmFit(qn_f2, fakemod3)
qn4_cb <- lmFit(qn_f2, fakemod4)


saveRDS(qn1_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn1_nocb.RDS"))
saveRDS(qn2_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn2_nocb.RDS"))
saveRDS(qn3_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn3_nocb.RDS"))
saveRDS(qn4_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn4_nocb.RDS"))

saveRDS(qn1_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn1_cbeff.RDS"))
saveRDS(qn2_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn2_cbeff.RDS"))
saveRDS(qn3_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn3_cbeff.RDS"))
saveRDS(qn4_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn4_cbeff.RDS"))

saveRDS(qn1_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn1_cb.RDS"))
saveRDS(qn2_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn2_cb.RDS"))
saveRDS(qn3_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn3_cb.RDS"))
saveRDS(qn4_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/qn4_cb.RDS"))


saveRDS(qn_f1, file=paste0(datpath, "/Methods Comparison Data/Intermediate Datasets/QN_ComBat_EffectSpec.RDS"))
saveRDS(qn_f2, file=paste0(datpath, "/Methods Comparison Data/Intermediate Datasets/QN_ComBat_NoEffect.RDS"))

rm(qn.mvals, qn1_nocb, qn2_nocb, qn3_nocb, qn4_nocb, qn1_cbeff, qn2_cbeff, qn3_cbeff, qn4_cbeff,
   qn1_cb, qn2_cb, qn3_cb, qn4_cb, qn_f1, qn_f2)



#-----------------------------------------------------------------
# ComBat Processing and Analysis for BMIQ Data and Fake Group ----
#-----------------------------------------------------------------

bmiq.mvals <- readRDS(paste0(datpath, "/Main paper data/Analysis Datasets/bmiq.mvals.main.RDS"))
bmiq_f1 <- ComBat(bmiq.mvals, batch=metafake$Sentrix_Barcode, mod=fakemod1)
# note: found 11 genes with uniform expression within a single batch (all zeros); these will not be adjusted for batch
# (this error does not appear in the QN data)
bmiq_f2 <- ComBat(bmiq.mvals, batch=metafake$Sentrix_Barcode)
# same warning regarding 11 genes with uniform expression within batch

## Analyses ##

# run limma on non-ComBat processed dataset, adjusting for batch and also getting effect of infant sex in second model
metafake <- metafake[match(metafake$sample, colnames(bmiq.mvals)),]
bmiq1_nocb <- lmFit(bmiq.mvals, fakemod1)
bmiq2_nocb <- lmFit(bmiq.mvals, fakemod2)
bmiq3_nocb <- lmFit(bmiq.mvals, fakemod3)
bmiq4_nocb <- lmFit(bmiq.mvals, fakemod4)

# ComBat-processed dataset
metafake <- metafake[match(metafake$sample, colnames(bmiq_f1)),]
bmiq1_cbeff <- lmFit(bmiq_f1, fakemod1)
bmiq2_cbeff <- lmFit(bmiq_f1, fakemod2)
bmiq3_cbeff <- lmFit(bmiq_f1, fakemod3)
bmiq4_cbeff <- lmFit(bmiq_f1, fakemod4)

metafake <- metafake[match(metafake$sample, colnames(bmiq_f2)),]
bmiq1_cb <- lmFit(bmiq_f2, fakemod1)
bmiq2_cb <- lmFit(bmiq_f2, fakemod2)
bmiq3_cb <- lmFit(bmiq_f2, fakemod3)
bmiq4_cb <- lmFit(bmiq_f2, fakemod4)


saveRDS(bmiq1_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq1_nocb.RDS"))
saveRDS(bmiq2_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq2_nocb.RDS"))
saveRDS(bmiq3_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq3_nocb.RDS"))
saveRDS(bmiq4_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq4_nocb.RDS"))

saveRDS(bmiq1_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq1_cbeff.RDS"))
saveRDS(bmiq2_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq2_cbeff.RDS"))
saveRDS(bmiq3_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq3_cbeff.RDS"))
saveRDS(bmiq4_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq4_cbeff.RDS"))

saveRDS(bmiq1_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq1_cb.RDS"))
saveRDS(bmiq2_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq2_cb.RDS"))
saveRDS(bmiq3_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq3_cb.RDS"))
saveRDS(bmiq4_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/bmiq4_cb.RDS"))

saveRDS(bmiq_f1, file=paste0(datpath, "/Methods Comparison Data/Intermediate Datasets/BMIQ_ComBat_EffectSpec.RDS"))
saveRDS(bmiq_f2, file=paste0(datpath, "/Methods Comparison Data/Intermediate Datasets/BMIQ_ComBat_NoEffect.RDS"))


rm(bmiq.mvals, bmiq_f1, bmiq_f2, bmiq1_nocb, bmiq2_nocb, bmiq3_nocb, bmiq4_nocb, bmiq1_cbeff, bmiq2_cbeff, 
   bmiq3_cbeff, bmiq4_cbeff, bmiq1_cb, bmiq2_cb, bmiq3_cb, bmiq4_cb)


#-----------------------------------------------------------------
# ComBat Processing and Analysis for SWAN Data and Fake Group ----
#-----------------------------------------------------------------

swan.mvals <- readRDS(paste0(datpath, "/Main paper data/Analysis Datasets/swan.mvals.main.RDS"))
swan_f1 <- ComBat(swan.mvals, batch=metafake$Sentrix_Barcode, mod=fakemod1)
swan_f2 <- ComBat(swan.mvals, batch=metafake$Sentrix_Barcode)

## Analyses ##

# run limma on non-ComBat processed dataset, adjusting for batch and also getting effect of infant sex in second model
metafake <- metafake[match(metafake$sample, colnames(swan.mvals)),]
swan1_nocb <- lmFit(swan.mvals, fakemod1)
swan2_nocb <- lmFit(swan.mvals, fakemod2)
swan3_nocb <- lmFit(swan.mvals, fakemod3)
swan4_nocb <- lmFit(swan.mvals, fakemod4)

# ComBat-processed dataset
metafake <- metafake[match(metafake$sample, colnames(swan_f1)),]
swan1_cbeff <- lmFit(swan_f1, fakemod1)
swan2_cbeff <- lmFit(swan_f1, fakemod2)
swan3_cbeff <- lmFit(swan_f1, fakemod3)
swan4_cbeff <- lmFit(swan_f1, fakemod4)

metafake <- metafake[match(metafake$sample, colnames(swan_f2)),]
swan1_cb <- lmFit(swan_f2, fakemod1)
swan2_cb <- lmFit(swan_f2, fakemod2)
swan3_cb <- lmFit(swan_f2, fakemod3)
swan4_cb <- lmFit(swan_f2, fakemod4)


saveRDS(swan1_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan1_nocb.RDS"))
saveRDS(swan2_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan2_nocb.RDS"))
saveRDS(swan3_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan3_nocb.RDS"))
saveRDS(swan4_nocb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan4_nocb.RDS"))

saveRDS(swan1_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan1_cbeff.RDS"))
saveRDS(swan2_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan2_cbeff.RDS"))
saveRDS(swan3_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan3_cbeff.RDS"))
saveRDS(swan4_cbeff, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan4_cbeff.RDS"))

saveRDS(swan1_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan1_cb.RDS"))
saveRDS(swan2_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan2_cb.RDS"))
saveRDS(swan3_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan3_cb.RDS"))
saveRDS(swan4_cb, file=paste0(datpath, "/Methods Comparison Data/Model Fit Results/swan4_cb.RDS"))

saveRDS(swan_f1, file=paste0(datpath, "/Methods Comparison Data/Intermediate Datasets/SWAN_ComBat_EffectSpec.RDS"))
saveRDS(swan_f2, file=paste0(datpath, "/Methods Comparison Data/Intermediate Datasets/SWAN_ComBat_NoEffect.RDS"))


rm(swan.mvals, swan_f1, swan_f2, swan1_nocb, swan2_nocb, swan3_nocb, swan4_nocb, swan1_cbeff, swan2_cbeff, 
   swan3_cbeff, swan4_cbeff, swan1_cb, swan2_cb, swan3_cb, swan4_cb)
