#--------------------------------------------------------------------------#
#                                                                          #
#   LIMIT DNAm Methods Comparison Paper: Treatment Group and BMI Effects   #
#                                                                          #
#   Jennie L                                                 August 2021   #
#                                                                          #
#--------------------------------------------------------------------------#

library(limma)
library(sva)

datpath <- "/Volumes/JENNIE/O&G data/LIMIT DNAm Data/"

# metadata (includes cell type proportions estimated using minfi estimateCellCounts)

metadata <- readRDS(file.path(datpath, "Base Datasets/metadata.RDS"))
# mean-centre BMI #
metadata$bmic <- with(metadata, BMIClinic - mean(BMIClinic))


#______________________________________
#                                     -
#  Subset Quantile Normalised Data ----
#                                     -
#______________________________________

#_______________________________
#  1. No ComBat Processing  ----
#_______________________________

qn.mvals <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.main.RDS"))

metadata <- metadata[match(colnames(qn.mvals), metadata$sample),]

# 1. BMI*Treatment Group
mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
# 2. BMI*Treatment Group + Batch
mod2 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode), data=metadata)
# 3. BMI*Treatment Group + Batch + Cell Type
mod3 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode) + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

qn1 <- lmFit(qn.mvals, mod1)
qn2 <- lmFit(qn.mvals, mod2)
qn3 <- lmFit(qn.mvals, mod3)

saveRDS(qn1, file.path(datpath, "Model Fit Results/Methods Comparison/qn_main1.RDS"))
saveRDS(qn2, file.path(datpath, "Model Fit Results/Methods Comparison/qn_main2.RDS"))
saveRDS(qn3, file.path(datpath, "Model Fit Results/Methods Comparison/qn_main3.RDS"))

#_____________________________________________________
#  2. ComBat Processing With Effect Specification ----
#_____________________________________________________

qn.mvals.cb <- readRDS(file.path(datpath, "BatchCorrected Data/qn.mvals.sCB.RDS"))
metadata <- metadata[match(colnames(qn.mvals.cb), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

qneff1 <- lmFit(qn.mvals.cb, mod1)
qneff3 <- lmFit(qn.mvals.cb, mod3)

saveRDS(qneff1, file.path(datpath, "Model Fit Results/Methods Comparison/qn_main_scb1.RDS"))
saveRDS(qneff3, file.path(datpath, "Model Fit Results/Methods Comparison/qn_main_scb3.RDS"))


#________________________________________________________
#  3. ComBat Processing Without Effect Specification ----
#________________________________________________________

qn.mvals.cb2 <- readRDS(file.path(datpath, "BatchCorrected Data/qn.mvals.uCB.RDS"))
metadata <- metadata[match(colnames(qn.mvals.cb2), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

qncb1 <- lmFit(qn.mvals.cb2, mod1)
qncb3 <- lmFit(qn.mvals.cb2, mod3)

saveRDS(qncb1, file.path(datpath, "Model Fit Results/Methods Comparison/qn_main_ucb1.RDS"))
saveRDS(qncb3, file.path(datpath, "Model Fit Results/Methods Comparison/qn_main_ucb3.RDS"))

#--------------------------------------------------------------------
#  4. Probe Filtering Before Normalisation: No ComBat Processing ----
#--------------------------------------------------------------------

qn.mvals <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.filt.RDS"))
metadata <- metadata[match(colnames(qn.mvals), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod2 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode), data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode) + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

qn1 <- lmFit(qn.mvals, mod1)
qn2 <- lmFit(qn.mvals, mod2)
qn3 <- lmFit(qn.mvals, mod3)

saveRDS(qn1, file.path(datpath, "Model Fit Results/Methods Comparison/qn_filt1.RDS"))
saveRDS(qn2, file.path(datpath, "Model Fit Results/Methods Comparison/qn_filt2.RDS"))
saveRDS(qn3, file.path(datpath, "Model Fit Results/Methods Comparison/qn_filt3.RDS"))


#___________________________________________________________________________________________
#  5. Probe Filtering Before Normalisation: ComBat Processing With Effect Specification ----
#___________________________________________________________________________________________

qn.mvals.cb <- readRDS(file.path(datpath, "BatchCorrected Data/qn.filt.sCB.RDS"))
metadata <- metadata[match(colnames(qn.mvals.cb), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

qneff1 <- lmFit(qn.mvals.cb, mod1)
qneff3 <- lmFit(qn.mvals.cb, mod3)

saveRDS(qneff1, file.path(datpath, "Model Fit Results/Methods Comparison/qn_filt_scb1.RDS"))
saveRDS(qneff3, file.path(datpath, "Model Fit Results/Methods Comparison/qn_filt_scb3.RDS"))



#______________________________________________________________________________________________
#  6. Probe Filtering Before Normalisation: ComBat Processing Without Effect Specification ----
#______________________________________________________________________________________________

qn.mvals.cb2 <- readRDS(file.path(datpath, "BatchCorrected Data/qn.filt.uCB.RDS"))

metadata <- metadata[match(colnames(qn.mvals.cb2), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

qncb1 <- lmFit(qn.mvals.cb2, mod1)
qncb3 <- lmFit(qn.mvals.cb2, mod3)

saveRDS(qncb1, file.path(datpath, "Model Fit Results/Methods Comparison/qn_filt_ucb1.RDS"))
saveRDS(qncb3, file.path(datpath, "Model Fit Results/Methods Comparison/qn_filt_ucb3.RDS"))

rm(qn.mvals, qn.mvals.cb, qn.mvals.cb2, qn1, qn2, qn3, qneff1, qneff3,
   qncb1, qncb3, mod1, mod2, mod3)

#-----------------------------------------#
#  7. Adjustment for Surrogate Variables  #
#-----------------------------------------#

## Surrogate Variables Estimated on Main Data (probe filtering after normalisation)
qn.mvals.main <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.main.RDS"))
metadata <- metadata[match(colnames(qn.mvals.main), metadata$sample),]

qn.main.sva <- readRDS(file.path(datpath, "Base Datasets/qn.main.sva.RDS"))  # 48 surrogate variables

# create model matrix with BMI and Treatment then add the surrogate variables to it
modmat <- model.matrix(~ Treatment*bmic, data=metadata)
modsva <- cbind(modmat, qn.main.sva$sv)

qn.sva.main <- lmFit(qn.mvals.main, modsva)
saveRDS(qn.sva.main, file.path(datpath, "Model Fit Results/Methods Comparison/qn.sva.main.RDS"))

rm(qn.mvals.main, qn.main.sva, qn.sva.main)

## Surrogate Variables Estimated on Filt Data (probe filtering before normalisation)
qn.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.filt.RDS"))
metadata <- metadata[match(colnames(qn.mvals.filt), metadata$sample),]

qn.filt.sva <- readRDS(file.path(datpath, "Base Datasets/qn.filt.sva.RDS"))  # 48 surrogate variables

modmat <- model.matrix(~Treatment*bmic, data=metadata)
modsva <- cbind(modmat, qn.filt.sva$sv)

qn.sva.filt <- lmFit(qn.mvals.filt, modsva)
saveRDS(qn.sva.filt, file.path(datpath, "Model Fit Results/Methods Comparison/qn.sva.filt.RDS"))

rm(qn.mvals.filt, qn.filt.sva, qn.sva.filt)


#____________________________________________
#                                           -
#  Beta Mixture Quantile Normalised Data ----
#                                           -
#____________________________________________

#______________________________
#  1. No ComBat Processing ----
#______________________________

bmiq.mvals <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.main.RDS"))
metadata <- metadata[match(colnames(bmiq.mvals), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod2 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode), data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode) + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

bmiq1 <- lmFit(bmiq.mvals, mod1)
bmiq2 <- lmFit(bmiq.mvals, mod2)
bmiq3 <- lmFit(bmiq.mvals, mod3)

saveRDS(bmiq1, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_main1.RDS"))
saveRDS(bmiq2, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_main2.RDS"))
saveRDS(bmiq3, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_main3.RDS"))


#___________________________________________________________
#  2. ComBat Processing With Specification of Effects  -----
#___________________________________________________________

bmiq.mvals.cb <- readRDS(file.path(datpath, "BatchCorrected Data/bmiq.mvals.sCB.RDS"))
metadata <- metadata[match(colnames(bmiq.mvals.cb), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

bmiqeff1 <- lmFit(bmiq.mvals.cb, mod1)
bmiqeff3 <- lmFit(bmiq.mvals.cb, mod3)

saveRDS(bmiqeff1, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_main_scb1.RDS"))
saveRDS(bmiqeff3, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_main_scb3.RDS"))

#____________________________________________________________
#  3. ComBat Processing Without Specification of Effects ----
#____________________________________________________________

bmiq.mvals.cb2 <- readRDS(file.path(datpath, "BatchCorrected Data/bmiq.mvals.uCB.RDS"))
metadata <- metadata[match(colnames(bmiq.mvals.cb2), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

bmiqcb1 <- lmFit(bmiq.mvals.cb2, mod1)
bmiqcb3 <- lmFit(bmiq.mvals.cb2, mod3)

saveRDS(bmiqcb1, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_main_ucb1.RDS"))
saveRDS(bmiqcb3, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_main_ucb3.RDS"))


#--------------------------------------------------------------------
#  4. Probe Filtering Before Normalisation: No ComBat Processing ----
#--------------------------------------------------------------------

bmiq.mvals <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.filt.RDS"))
metadata <- metadata[match(colnames(bmiq.mvals), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod2 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode), data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode) + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

bmiq1 <- lmFit(bmiq.mvals, mod1)
bmiq2 <- lmFit(bmiq.mvals, mod2)
bmiq3 <- lmFit(bmiq.mvals, mod3)

saveRDS(bmiq1, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_filt1.RDS"))
saveRDS(bmiq2, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_filt2.RDS"))
saveRDS(bmiq3, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_filt3.RDS"))


#___________________________________________________________________________________________
#  5. Probe Filtering Before Normalisation: ComBat Processing With Effect Specification ----
#___________________________________________________________________________________________

bmiq.mvals.cb <- readRDS(file.path(datpath, "BatchCorrected Data/bmiq.filt.sCB.RDS"))
metadata <- metadata[match(colnames(bmiq.mvals.cb), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

bmiqeff1 <- lmFit(bmiq.mvals.cb, mod1)
bmiqeff3 <- lmFit(bmiq.mvals.cb, mod3)

saveRDS(bmiqeff1, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_filt_scb1.RDS"))
saveRDS(bmiqeff3, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_filt_scb3.RDS"))


#______________________________________________________________________________________________
#  6. Probe Filtering Before Normalisation: ComBat Processing Without Effect Specification ----
#______________________________________________________________________________________________

bmiq.mvals.cb2 <- readRDS(file.path(datpath, "BatchCorrected Data/bmiq.filt.uCB.RDS"))

metadata <- metadata[match(colnames(bmiq.mvals.cb2), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

bmiqcb1 <- lmFit(bmiq.mvals.cb2, mod1)
bmiqcb3 <- lmFit(bmiq.mvals.cb2, mod3)

saveRDS(bmiqcb1, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_filt_ucb1.RDS"))
saveRDS(bmiqcb3, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq_filt_ucb3.RDS"))

rm(bmiq.mvals, bmiq.mvals.cb, bmiq.mvals.cb2, bmiq1, bmiq2, bmiq3, bmiqcb1, bmiqcb3, bmiqeff1, bmiqeff3)

#---------------------#
#  7. SVA Adjustment  #
#---------------------#

## Surrogate Variables Estimated on Main Data (probe filtering after normalisation)
bmiq.mvals.main <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.main.RDS"))
metadata <- metadata[match(colnames(bmiq.mvals.main), metadata$sample),]

bmiq.main.sva <- readRDS(file.path(datpath, "Base Datasets/bmiq.main.sva.RDS"))  #  39 surrogate variables

# create model matrix with BMI and Treatment then add the surrogate variables to it
modmat <- model.matrix(~ Treatment*bmic, data=metadata)
modsva <- cbind(modmat, bmiq.main.sva$sv)

bmiq.sva.main <- lmFit(bmiq.mvals.main, modsva)
saveRDS(bmiq.sva.main, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq.sva.main.RDS"))

rm(bmiq.mvals.main, bmiq.main.sva, bmiq.sva.main)

## Surrogate Variables Estimated on Filt Data (probe filtering before normalisation)
bmiq.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.filt.RDS"))
metadata <- metadata[match(colnames(bmiq.mvals.filt), metadata$sample),]

bmiq.filt.sva <- readRDS(file.path(datpath, "Base Datasets/bmiq.filt.sva.RDS"))  #  41 surrogate variables

modmat <- model.matrix(~Treatment*bmic, data=metadata)
modsva <- cbind(modmat, bmiq.filt.sva$sv)

bmiq.sva.filt <- lmFit(bmiq.mvals.filt, modsva)
saveRDS(bmiq.sva.filt, file.path(datpath, "Model Fit Results/Methods Comparison/bmiq.sva.filt.RDS"))

rm(bmiq.mvals.filt, bmiq.filt.sva, bmiq.sva.filt)

#____________________________________________
#                                           -
#   Subset Within-Quantile Normalisation ----
#                                           -
#____________________________________________

#______________________________
#  1. No ComBat Processing ----
#______________________________

swan.mvals <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.main.RDS"))
metadata <- metadata[match(colnames(swan.mvals), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod2 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode), data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode) + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

swan1 <- lmFit(swan.mvals, mod1)
swan2 <- lmFit(swan.mvals, mod2)
swan3 <- lmFit(swan.mvals, mod3)

saveRDS(swan1, file.path(datpath, "Model Fit Results/Methods Comparison/swan_main1.RDS"))
saveRDS(swan2, file.path(datpath, "Model Fit Results/Methods Comparison/swan_main2.RDS"))
saveRDS(swan3, file.path(datpath, "Model Fit Results/Methods Comparison/swan_main3.RDS"))

#_________________________________________________________
#  2. ComBat Processing With Specification of Effects ----
#_________________________________________________________

swan.mvals.cb <- readRDS(file.path(datpath, "BatchCorrected Data/swan.mvals.sCB.RDS"))
metadata <- metadata[match(colnames(swan.mvals.cb), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

swaneff1 <- lmFit(swan.mvals.cb, mod1)
swaneff3 <- lmFit(swan.mvals.cb, mod3)

saveRDS(swaneff1, file.path(datpath, "Model Fit Results/Methods Comparison/swan_main_scb1.RDS"))
saveRDS(swaneff3, file.path(datpath, "Model Fit Results/Methods Comparison/swan_main_scb3.RDS"))

#____________________________________________________________
#  3. ComBat Processing Without Specification of Effects ----
#____________________________________________________________

swan.mvals.cb2 <- readRDS(file.path(datpath, "BatchCorrected Data/swan.mvals.uCB.RDS"))
metadata <- metadata[match(colnames(swan.mvals.cb2), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

swancb1 <- lmFit(swan.mvals.cb2, mod1)
swancb3 <- lmFit(swan.mvals.cb2, mod3)

saveRDS(swancb1, file.path(datpath, "Model Fit Results/Methods Comparison/swan_main_ucb1.RDS"))
saveRDS(swancb3, file.path(datpath, "Model Fit Results/Methods Comparison/swan_main_ucb3.RDS"))


#--------------------------------------------------------------------
#  4. Probe Filtering Before Normalisation: No ComBat Processing ----
#--------------------------------------------------------------------

swan.mvals <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.filt.RDS"))
metadata <- metadata[match(colnames(swan.mvals), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod2 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode), data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + factor(Sentrix_Barcode) + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

swan1 <- lmFit(swan.mvals, mod1)
swab2 <- lmFit(swan.mvals, mod2)
swan3 <- lmFit(swan.mvals, mod3)

saveRDS(swan1, file.path(datpath, "Model Fit Results/Methods Comparison/swan_filt1.RDS"))
saveRDS(swan2, file.path(datpath, "Model Fit Results/Methods Comparison/swan_filt2.RDS"))
saveRDS(swan3, file.path(datpath, "Model Fit Results/Methods Comparison/swan_filt3.RDS"))


#___________________________________________________________________________________________
#  5. Probe Filtering Before Normalisation: ComBat Processing With Effect Specification ----
#___________________________________________________________________________________________

swan.mvals.cb <- readRDS(file.path(datpath, "BatchCorrected Data/swan.filt.sCB.RDS"))
metadata <- metadata[match(colnames(swan.mvals.cb), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

swaneff1 <- lmFit(swan.mvals.cb, mod1)
swaneff3 <- lmFit(swan.mvals.cb, mod3)

saveRDS(swaneff1, file.path(datpath, "Model Fit Results/Methods Comparison/swan_filt_scb1.RDS"))
saveRDS(swaneff3, file.path(datpath, "Model Fit Results/Methods Comparison/swan_filt_scb3.RDS"))


#______________________________________________________________________________________________
#  6. Probe Filtering Before Normalisation: ComBat Processing Without Effect Specification ----
#______________________________________________________________________________________________

swan.mvals.cb2 <- readRDS(file.path(datpath, "BatchCorrected Data/swan.filt.uCB.RDS"))
metadata <- metadata[match(colnames(swan.mvals.cb2), metadata$sample),]

mod1 <- model.matrix(~ Treatment*bmic, data=metadata)
mod3 <- model.matrix(~ Treatment*bmic + Bcell + CD4T + CD8T + Gran + Mono + NK + nRBC, data=metadata)

swancb1 <- lmFit(swan.mvals.cb2, mod1)
swancb3 <- lmFit(swan.mvals.cb2, mod3)

saveRDS(swancb1, file.path(datpath, "Model Fit Results/Methods Comparison/swan_filt_ucb1.RDS"))
saveRDS(swancb3, file.path(datpath, "Model Fit Results/Methods Comparison/swan_filt_ucb3.RDS"))

rm(swan.mvals, swan.mvals.cb, swan.mvals.cb2, swan1, swan2, swan3, swaneff1, swaneff3, swancb1, swancb3)


#----------------------#
#  7.  SVA Adjustment  #
#----------------------#


## Surrogate Variables Estimated on Main Data (probe filtering after normalisation)
swan.mvals.main <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.main.RDS"))
metadata <- metadata[match(colnames(swan.mvals.main), metadata$sample),]

swan.main.sva <- readRDS(file.path(datpath, "Base Datasets/swan.main.sva.RDS"))  # 30 surrogate variables

# create model matrix with BMI and Treatment then add the surrogate variables to it
modmat <- model.matrix(~ Treatment*bmic, data=metadata)
modsva <- cbind(modmat, swan.main.sva$sv)

swan.sva.main <- lmFit(swan.mvals.main, modsva)
saveRDS(swan.sva.main, file.path(datpath, "Model Fit Results/Methods Comparison/swan.sva.main.RDS"))

rm(swan.mvals.main, swan.main.sva, swan.sva.main)

## Surrogate Variables Estimated on Filt Data (probe filtering before normalisation)
swan.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.filt.RDS"))
metadata <- metadata[match(colnames(swan.mvals.filt), metadata$sample),]

swan.filt.sva <- readRDS(file.path(datpath, "Base Datasets/swan.filt.sva.RDS"))  # 30 surrogate variables

modmat <- model.matrix(~Treatment*bmic, data=metadata)
modsva <- cbind(modmat, swan.filt.sva$sv)

swan.sva.filt <- lmFit(swan.mvals.filt, modsva)
saveRDS(swan.sva.filt, file.path(datpath, "Model Fit Results/Methods Comparison/swan.sva.filt.RDS"))

rm(swan.mvals.filt, swan.filt.sva, swan.sva.filt)

