#----------------------------------------------------------------------------------#
#                                                                                  #
#  Normalisation of LIMIT Cord Blood DNA Methylation Data                          #
#                                                                                  #
#  Jennie L                                                          October 2021  #
#                                                                                  #
#----------------------------------------------------------------------------------#

## Run October 2021 using R version

library(ChAMP)
library(minfi)
library(sva)
library(DMRcate)
library(doParallel)
library(lumi)

datpath <- "/Volumes/JENNIE/O&G data/LIMIT DNAm Data/"

# targets with faulty samples removed
targets_filtered <- readRDS(file.path(datpath, "Base Datasets/targets_filtered.RDS"))
# GMSet (targets converted into GMSet object without normalisation (using preprocessRaw in minfi))
GMSet.raw <- readRDS(file.path(datpath, "Base Datasets/GMSet.Raw.RDS"))


# detection P values for targets - to get a set of faulty probes to remove
detP_filt <- detectionP(targets_filtered)
# advice is to perform probe filtering after normalisation; however the filtering does not depend on normalised values.
# get a dataset of probes to keep (those which failed - defined as detection P >=0.001 -  in less than 25% of samples)
keep <- subset(detP_filt, rowSums(detP_filt >= 0.001) < 161)
# how many probes will be removed
nrow(detP_filt) - nrow(keep)


## Subset Quantile Normalisation ##

# preprocessQuantile approach - not using any of the non-default options (e.g. remove bad samples)
QN.GMSet <- preprocessQuantile(GMSet.raw)

# Quantile normalised data density plot
densityPlot(getBeta(QN.GMSet))

# Remove the 'failed' probes from the quantile normalised dataset (using 25% criterion)
QN.GMSet_filt <- QN.GMSet[rownames(QN.GMSet) %in% rownames(keep),]
dim(QN.GMSet_filt)

##  Use DMRcate function to remove SNPs, cross-hybridizing probes (set maf cutoff of 0.01) and probes on X and Y chromosomes
qn.mvals <- getM(QN.GMSet_filt)
qn.mvals <- rmSNPandCH(qn.mvals, dist=3, mafcut=0.01, and=TRUE, rmcrosshyb=TRUE, rmXY=TRUE)
dim(qn.mvals)
saveRDS(qn.mvals, file.path(datpath, "Normalised Data/qn.mvals.main.RDS"))

rm(QN.GMSet, QN.GMSet_filt)



##  BMIQ  Normalisation ##

# champ.norm requires beta values as input
betas <- getBeta(GMSet.raw, type = 'Illumina')

# BMIQ normalisation (note this currently fails with more than 1 core, not sure what the problem is)
BMIQ.Betas <- champ.norm(beta=betas, method="BMIQ", plotBMIQ=T, cores=4)

# as before, filter out probes that failed in more than 25% of samples
bmiq_filt <- BMIQ.Betas[rownames(BMIQ.Betas) %in% rownames(keep),]

# Remove SNPs, CH and XY probes
bmiq_filt <- rmSNPandCH(bmiq_filt, dist=3, mafcut=0.01, and=T, rmcrosshyb=T, rmXY=T)

# convert to M values (using lumi beta2m) for analysis
bmiqm_filt <- beta2m(bmiq_filt)

saveRDS(bmiqm_filt, file.path(datpath, "Normalised Data/bmiq.mvals.main.RDS"))


##  SWAN Normalisation ## 

set.seed(131021) # per documentation, to achieve reproducible results since random selection of probes used for between-array normalisation
GMSet.SWAN <- preprocessSWAN(targets_filtered, mSet=GMSet.raw)

# Remove the 'failed' probes from the SWAN normalised dataset (using 25% criterion)
swan_filt <- GMSet.SWAN[rownames(GMSet.SWAN) %in% rownames(keep),]

## (2) and (3) Use DMRcate function to remove SNPs and cross-hybridizing probes (set maf cutoff of 0.05), and XY probes
swan_filt <- getM(swan_filt)
swan_filt <- rmSNPandCH(swan_filt, dist=3, mafcut=0.01, and=TRUE, rmcrosshyb=TRUE, rmXY=TRUE)

saveRDS(swan_filt, file.path(datpath, "Normalised Data/swan.mvals.main.RDS"))



#-------------------------------------------------#
#                                                 #
#   Remove Faulty Probes Prior to Normalisation   #
#                                                 #
#-------------------------------------------------#


## Subset Quantile Normalisation ##

# Note that the preprocessQuantile function will not work properly if XY probes are removed beforehand
# (creates error in kmeans "initial centers are not distinct" - diagnosis per discussion on github 
# https://github.com/hansenlab/minfi/issues/179)

# remove faulty probes only then remove cross-hybridising, SNPs and XYs after normalisation

GMSet.filt <- subset(GMSet.raw, rownames(GMSet.raw) %in% rownames(keep))
mvals.filt <- getM(GMSet.filt)
mvals.filt <- rmSNPandCH(mvals.filt, dist=3, mafcut=0.01, and=T, rmcrosshyb=T, rmXY=F)

GMSet.filt2 <- subset(GMSet.filt, rownames(GMSet.filt) %in% rownames(mvals.filt))

QN.GMSet.filt <- preprocessQuantile(GMSet.filt2)

# remove probes on XY
qn.mvals.filt <- getM(QN.GMSet.filt)
qn.mvals.filt <- rmSNPandCH(qn.mvals.filt, dist=3, mafcut=0.01, and=T, rmcrosshyb=T, rmXY=T)

dim(qn.mvals.filt)
saveRDS(qn.mvals.filt, file.path(datpath, "Normalised Data/qn.mvals.filt.RDS"))


## BMIQ Normalisation ##

mvals.filt <- getM(GMSet.filt)
mvals.filt <- rmSNPandCH(mvals.filt, dist=3, mafcut=0.01, and=T, rmcrosshyb=T, rmXY=T)

betas.filt <- subset(betas, rownames(betas) %in% rownames(mvals.filt))

# BMIQ normalisation (note this currently fails with more than 1 core, not sure what the problem is)
set.seed(131021)
BMIQ.Betas.filt <- champ.norm(beta=betas.filt, method="BMIQ", plotBMIQ=TRUE, cores=4)

# convert to mvals
BMIQ.M.filt <- beta2m(BMIQ.Betas.filt)

saveRDS(BMIQ.M.filt, file.path(datpath, "Normalised Data/bmiq.mvals.filt.RDS"))


## SWAN Normalisation ##

# Need to remove the excluded probes from the rgSet object which is not simple since targets_filtered is not indexed by probe name
rgset_filt <- subsetByLoci(targets_filtered, includeLoci=rownames(mvals.filt))
# check that this actually worked
#chk <- preprocessRaw(rgset_filt) # OK
# save so I can read it in later (for estimateCellCounts)
saveRDS(rgset_filt, file.path(datpath, "Base Datasets/rgset_filt.RDS"))

set.seed(131021)
SWAN.GMSet.filt <- preprocessSWAN(rgset_filt, mSet=GMSet.filt2)

SWAN.M.filt <- getM(SWAN.GMSet.filt)

saveRDS(SWAN.M.filt, file.path(datpath, "Normalised Data/swan.mvals.filt.RDS"))


rm(betas, betas.filt, BMIQ.Betas.filt, BMIQ.M.filt, detP_filt, GMSet.filt, GMSet.filt2, GMSet.raw, GMSet.SWAN, keep,
   mvals.filt, probeInfoALL.lv, rgset_filt, swan_filt, SWAN.GMSet.filt, SWAN.M.filt, targets_filtered)


#----------------------------------------------------#
#                                                    
#   ComBat Batch-Correction Algorithm ----
#                                                    
#----------------------------------------------------#


# Read in metadata (which contains batch information as well as BMI, Intervention for supervised algorithm)

# metadata (sample name, BMI, treatment group etc)
metadata <- readRDS(file.path(datpath, "Base Datasets/metadata.RDS"))

## SQN Data ##

## 1. Data where probe filtering (faulty + SNPs, CH, XY probes) done after normalisation
qn.mvals.main <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.main.RDS"))

# make sure they are sorted in the same order
metadata <- metadata[match(metadata$sample, colnames(qn.mvals.main)),]

# Supervised ComBat:
modmat <- model.matrix( ~ Treatment*BMIClinic, data=metadata)
qn.mvals.sCB <- ComBat(qn.mvals.main, batch=metadata$Sentrix_Barcode, mod=modmat) 
saveRDS(qn.mvals.sCB, file.path(datpath, "BatchCorrected Data/qn.mvals.sCB.RDS"))

# UnSupervised ComBat
qn.mvals.uCB <- ComBat(qn.mvals.main, batch=metadata$Sentrix_Barcode)
saveRDS(qn.mvals.uCB, file.path(datpath, "BatchCorrected Data/qn.mvals.uCB.RDS"))

## 2. Data where probe filtering (with exception of XY, required to make preprocessQuantile work) done prior to normalisation
qn.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.filt.RDS"))
metadata <- metadata[match(metadata$sample, colnames(qn.mvals.filt)),]
modmat <- model.matrix(~Treatment*BMIClinic, data=metadata) # creating again in case the ordering of rows has changed

# Supervised
qn.filt.sCB <- ComBat(qn.mvals.filt, batch=metadata$Sentrix_Barcode, mod=modmat)
saveRDS(qn.filt.sCB, file.path(datpath, "BatchCorrected Data/qn.filt.sCB.RDS"))

# Unsupervised
qn.filt.uCB <- ComBat(qn.mvals.filt, batch=metadata$Sentrix_Barcode)
saveRDS(qn.filt.uCB, file.path(datpath, "BatchCorrected Data/qn.filt.uCB.RDS"))

rm(qn.mvals.main, qn.mvals.sCB, qn.mvals.uCB, qn.mvals.filt, qn.filt.sCB, qn.filt.uCB)


## BMIQ Data ##

## 1. Data where probe filtering was undertaken after normalisation
bmiq.mvals.main <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.main.RDS"))

metadata <- metadata[match(metadata$sample, colnames(bmiq.mvals.main)),]
modmat <- model.matrix( ~ Treatment*BMIClinic, data=metadata)

# Supervised ComBat
bmiq.mvals.sCB <- ComBat(bmiq.mvals.main, batch=metadata$Sentrix_Barcode, mod=modmat)
# Message: Found 10 genes with uniform expression within a single batch (all zeros); these will not be adjusted for batch.
saveRDS(bmiq.mvals.sCB, file.path(datpath, "BatchCorrected Data/bmiq.mvals.sCB.RDS"))

# UnSupervised ComBat
bmiq.mvals.uCB <- ComBat(bmiq.mvals.main, batch=metadata$Sentrix_Barcode)
# Message: Found 10 genes with uniform expression within a single batch (all zeros); these will not be adjusted for batch.
saveRDS(bmiq.mvals.uCB, file.path(datpath, "BatchCorrected Data/bmiq.mvals.uCB.RDS"))

## 2. Data where probe filtering was undertaken prior to normalisation

bmiq.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.filt.RDS"))
metadata <- metadata[match(metadata$sample, colnames(bmiq.mvals.filt)),]
modmat <- model.matrix(~ Treatment*BMIClinic, data=metadata)

# Supervised
bmiq.filt.sCB <- ComBat(bmiq.mvals.filt, batch=metadata$Sentrix_Barcode, mod=modmat)
# Message: Found 10 genes with uniform expression within a single batch (all zeros); these will not be adjusted for batch.
saveRDS(bmiq.filt.sCB, file.path(datpath, "BatchCorrected Data/bmiq.filt.sCB.RDS"))

# Unsupervised
bmiq.filt.uCB <- ComBat(bmiq.mvals.filt, batch=metadata$Sentrix_Barcode)
# Message: Found 10 genes with uniform expression within a single batch (all zeros); these will not be adjusted for batch.
saveRDS(bmiq.filt.uCB, file.path(datpath, "BatchCorrected Data/bmiq.filt.uCB.RDS"))

rm(bmiq.mvals.main, bmiq.mvals.filt, bmiq.mvals.sCB, bmiq.mvals.uCB, bmiq.filt.sCB, bmiq.filt.uCB)

## SWAN Data ##

## 1. Data where probe filtering was undertaken after normalisation

swan.mvals.main <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.main.RDS"))
metadata <- metadata[match(metadata$sample, colnames(swan.mvals.main)),]
modmat <- model.matrix(~ Treatment*BMIClinic, data=metadata)

# Supervised
swan.mvals.sCB <- ComBat(swan.mvals.main, batch=metadata$Sentrix_Barcode, mod=modmat)
saveRDS(swan.mvals.sCB, file.path(datpath, "BatchCorrected Data/swan.mvals.sCB.RDS"))

# Unsupervised
swan.mvals.uCB <- ComBat(swan.mvals.main, batch=metadata$Sentrix_Barcode)
saveRDS(swan.mvals.uCB, file.path(datpath, "BatchCorrected Data/swan.mvals.uCB.RDS"))

## 2. Data where probe filtering was undertaken prior to normalisation
swan.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.filt.RDS"))
metadata <- metadata[match(metadata$sample, colnames(swan.mvals.filt)),]
modmat <- model.matrix(~Treatment*BMIClinic, data=metadata)

# Supervised
swan.filt.sCB <- ComBat(swan.mvals.filt, batch=metadata$Sentrix_Barcode, mod=modmat)
saveRDS(swan.filt.sCB, file.path(datpath, "BatchCorrected Data/swan.filt.sCB.RDS"))

# Unsupervised
swan.filt.uCB <- ComBat(swan.mvals.filt, batch=metadata$Sentrix_Barcode)
saveRDS(swan.filt.uCB, file.path(datpath, "BatchCorrected Data/swan.filt.uCB.RDS"))

rm(swan.mvals.main, swan.mvals.filt, swan.mvals.sCB, swan.mvals.uCB, swan.filt.sCB, swan.filt.uCB)


#---------------------------------------------------#
#                                                   #
#   Estimate Cell Type Proportions for Adjustment   #
#                                                   #
#---------------------------------------------------#

#rgset_filt <- readRDS(file.path(datpath, "Base Datasets/rgset_filt.RDS")) ## faulty, SNP, CH, XY probes removed
# note estimateCellCounts will not work with the filtered probes (error initial centers are not distinct, probably because uses XY info)

targets_filtered <- readRDS(file.path(datpath, "Base Datasets/targets_filtered.RDS"))


# estimate cell proportions
cb.cell <- estimateCellCounts(targets_filtered, compositeCellType="CordBlood", processMethod="preprocessQuantile",
                              cellTypes=c( "Bcell", "CD4T", "CD8T", "Gran", "Mono", "NK", "nRBC"),
                              probeSelect="any", referencePlatform="IlluminaHumanMethylation450k",
                              meanPlot=F, verbose=F)

metadata <- merge(metadata, cb.cell, by.x="sample", by.y=0, all.x=T)

saveRDS(metadata, file.path(datpath, "Base Datasets/metadata.RDS"))

rm(cb.cell, FlowSorted.CordBlood.450k, targets_filtered)


#------------------------------------------------------------------------#
#                                                                         
#   Create Fake Groups and Run Supervised ComBat Algorithm Using Them ----
#                                                                         
#------------------------------------------------------------------------#

set.seed(14920)
metadata$fakegrp <- rbinom(645, 1, 0.5)
metadata$fakegrp <- factor(metadata$fakegrp, levels=c(0,1), labels=c("Tabby", "Tortoiseshell"))

metadata$fakegrp2 <- with(metadata, ifelse(fakegrp=="Tabby", rbinom(326, 1, 0.6), rbinom(319, 1, 0.6)))
with(metadata, table(fakegrp, fakegrp2))
metadata$fakegrp2 <- factor(metadata$fakegrp2, levels=c(0,1), labels=c("Long", "Short"))


metafake <- subset(metadata, select=c("StudyID", "sample", "Sentrix_Barcode", "BSex", "fakegrp", "fakegrp2",
                                      "Bcell", "CD4T", "CD8T", "Gran", "Mono", "NK", "nRBC"))

saveRDS(metafake, file.path(datpath,"Base Datasets/metadata_fake.RDS"))


## SQN Data ##

# 1. Probe filtering after normalisation
qn.mvals.main <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.main.RDS"))
metafake <- metafake[match(metafake$sample, colnames(qn.mvals.main)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

qn.main.fakeCB <- ComBat(qn.mvals.main, batch=metafake$Sentrix_Barcode, mod=modmat)
saveRDS(qn.main.fakeCB, file.path(datpath, "BatchCorrected Data/qn.main.fakeCB.RDS"))

# 2. Probe filtering before normalisation
qn.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.filt.RDS"))
metafake <- metafake[match(metafake$sample, colnames(qn.mvals.filt)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

qn.filt.fakeCB <- ComBat(qn.mvals.filt, batch=metafake$Sentrix_Barcode, mod=modmat)
saveRDS(qn.filt.fakeCB, file.path(datpath, "BatchCorrected Data/qn.filt.fakeCB.RDS"))

rm(qn.mvals.main, qn.mvals.filt, qn.main.fakeCB, qn.filt.fakeCB)

## BMIQ Data ##

# 1. Probe filtering after normalisation
bmiq.mvals.main <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.main.RDS"))
metafake <- metafake[match(metafake$sample, colnames(bmiq.mvals.main)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

bmiq.main.fakeCB <- ComBat(bmiq.mvals.main, batch=metafake$Sentrix_Barcode, mod=modmat)
saveRDS(bmiq.main.fakeCB, file.path(datpath, "BatchCorrected Data/bmiq.main.fakeCB.RDS"))

# 2. Probe filtering before normalisation
bmiq.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.filt.RDS"))
metafake <- metafake[match(metafake$sample, colnames(bmiq.mvals.filt)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

bmiq.filt.fakeCB <- ComBat(bmiq.mvals.filt, batch=metafake$Sentrix_Barcode, mod=modmat)
saveRDS(bmiq.filt.fakeCB, file.path(datpath, "BatchCorrected Data/bmiq.filt.fakeCB.RDS"))

rm(bmiq.mvals.main, bmiq.mvals.filt, bmiq.main.fakeCB, bmiq.filt.fakeCB)


## SWAN Data ##

# 1. Probe filtering after normalisation
swan.mvals.main <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.main.RDS"))
metafake <- metafake[match(metafake$sample, colnames(swan.mvals.main)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

swan.main.fakeCB <- ComBat(swan.mvals.main, batch=metafake$Sentrix_Barcode, mod=modmat)
saveRDS(swan.main.fakeCB, file.path(datpath, "BatchCorrected Data/swan.main.fakeCB.RDS"))

# 2. Probe filtering before normalisation
swan.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.filt.RDS"))
metafake <- metafake[match(metafake$sample, colnames(swan.mvals.filt)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

swan.filt.fakeCB <- ComBat(swan.mvals.filt, batch=metafake$Sentrix_Barcode, mod=modmat)
saveRDS(swan.filt.fakeCB, file.path(datpath, "BatchCorrected Data/swan.filt.fakeCB.RDS"))

rm(swan.mvals.main, swan.mvals.filt, swan.main.fakeCB, swan.filt.fakeCB)



#-----------------------------------#
#                                    
#   Surrogate Variable Analysis  ----
#                                    
#-----------------------------------#

# Can only be done as a supervised procedure #

#------------#
#  SQN Data  #
#------------#

##  1. probe filtering after normalisation

qn.mvals.main <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.main.RDS"))

# Intervention and BMI Effects
metadata <- metadata[match(metadata$sample, colnames(qn.mvals.main)),]
modmat <- model.matrix(~Treatment*BMIClinic, data=metadata)

qn.main.sva <- sva(qn.mvals.main, modmat)
saveRDS(qn.main.sva, file.path(datpath, "Base Datasets/qn.main.sva.RDS"))

# Fake Group Effects
metafake <- metafake[match(metafake$sample, colnames(qn.mvals.main)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

qn.main.fksva <- sva(qn.mvals.main, modmat)
saveRDS(qn.main.fksva, file.path(datpath, "Base Datasets/qn.main.fksva.RDS"))


## 2. Probe filtering before normalisation

qn.mvals.fit <- readRDS(file.path(datpath, "Normalised Data/qn.mvals.filt.RDS"))

# Intervention and BMI Effects
metadata <- metadata[match(metadata$sample, colnames(qn.mvals.filt)),]
modmat <- model.matrix(~Treatment*BMIClinic, data=metadata)

qn.filt.sva <- sva(qn.mvals.filt, modmat)
saveRDS(qn.filt.sva, file.path(datpath, "Base Datasets/qn.filt.sva.RDS"))

# Fake Group Effects
metafake <- metafake[match(metafake$sample, colnames(qn.mvals.filt)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

qn.filt.fksva <- sva(qn.mvals.filt, modmat)
saveRDS(qn.filt.fksva, file.path(datpath, "Base Datasets/qn.filt.fksva.RDS"))

rm(qn.mvals.main, qn.mvals.filt, qn.main.sva, qn.filt.sva, qn.main.fksva, qn.filt.fksva)


#-------------#
#  BMIQ Data  #
#-------------#

## 1. Probe filtering after normalisation
bmiq.mvals.main <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.main.RDS"))

# Intervention and BMI effects
metadata <- metadata[match(metadata$sample, colnames(bmiq.mvals.main)),]
modmat <- model.matrix(~Treatment*BMIClinic, data=metadata)

bmiq.main.sva <- sva(bmiq.mvals.main, modmat)
saveRDS(bmiq.main.sva, file.path(datpath, "Base Datasets/bmiq.main.sva.RDS"))

# Fake Group effecs
metafake <- metafake[match(metafake$sample, colnames(bmiq.mvals.main)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

bmiq.main.fksva <- sva(bmiq.mvals.main, modmat)
saveRDS(bmiq.main.fksva, file.path(datpath, "Base Datasets/bmiq.main.fksva.RDS"))

## 2. Probe filtering before normalisation
bmiq.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/bmiq.mvals.filt.RDS"))

# Intervention and BMI effects
metadata <- metadata[match(metadata$sample, colnames(bmiq.mvals.filt)),]
modmat <- model.matrix(~Treatment*BMIClinic, data=metadata)

bmiq.filt.sva <- sva(bmiq.mvals.filt, modmat)
saveRDS(bmiq.filt.sva, file.path(datpath, "Base Datasets/bmiq.filt.sva.RDS"))

# Fake Group Effects
metafake <- metafake[match(metafake$sample, colnames(bmiq.mvals.filt)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

bmiq.filt.fksva <- sva(bmiq.mvals.filt, modmat)
saveRDS(bmiq.filt.fksva, file.path(datpath, "Base Datasets/bmiq.filt.fksva.RDS"))

rm(bmiq.mvals.main, bmiq.mvals.filt, bmiq.main.sva, bmiq.filt.sva, bmiq.main.fksva, bmiq.filt.fksva)


#---------------#
#   SWAN Data   #
#---------------#

## 1. Probe filtering after normalisation
swan.mvals.main <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.main.RDS"))

# Intervention and BMI Effects
metadata <- metadata[match(metadata$sample, colnames(swan.mvals.main)),]
modmat <- model.matrix(~Treatment*BMI, data=metadata)

swan.main.sva <- sva(swan.mvals.main, modmat)
saveRDS(swan.main.sva, file.path(datpath, "Base Datasets/swan.main.sva.RDS"))

# Fake Group Effects
metafake <- metafake[match(metafake$sample, colnames(swan.mvals.main)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

swan.main.fksva <- sva(swan.mvals.main, modmat)
saveRDS(swan.main.fksva, file.path(datpath, "Base Datasets/swan.main.fksva.RDS"))

## 2. Probe filtering before normalisation
swan.mvals.filt <- readRDS(file.path(datpath, "Normalised Data/swan.mvals.filt.RDS"))

# Intervention and BMI Effects
metadata <- metadata[match(metadata$sample, colnames(swan.mvals.filt)),]
modmat <- model.matrix(~Treatment*BMIClinic, data=metadata)

swan.filt.sva <- sva(swan.mvals.filt, modmat)
saveRDS(swan.filt.sva, file.path(datpath, "Base Datasets/swan.filt.sva.RDS"))

# Fake Group Effects
metafake <- metafake[match(metafake$sample, colnames(swan.mvals.filt)),]
modmat <- model.matrix(~fakegrp*fakegrp2 + BSex, data=metafake)

swan.filt.fksva <- sva(swan.mvals.filt, modmat)
saveRDS(swan.filt.fksva, file.path(datpath, "Base Datasets/swan.filt.fksva.RDS"))

rm(swan.mvals.main, swan.mvals.filt, swan.main.sva, swan.filt.sva, swan.main.fksva, swan.filt.fksva)



